@@ -36,7 +36,6 @@ class MMO(Optimizer):
         """Initialization"""
         Optimizer.__init__(self)
 
-        self.X0 = None
         self.params = {}        
         self.method = {}
         
@@ -565,9 +564,7 @@ class MMO(Optimizer):
                 self.p_best = np.argmin(self.cB)
                 
                 # Update history
-                #if np.min(self.cX).f < self.results.cHistory[-1].f:
-                    #self.results.cHistory.append(np.min(self.cX).copy()) # superseded by progress_log()
-                self._progress_log(remark='(PSO)')
+                self._progress_log()
                 
                 # Check stopping conditions
                 if self._stopping_criteria():
@@ -602,9 +599,7 @@ class MMO(Optimizer):
                 self.cX = np.sort(self.cX)[:n]
     
                 # Update history
-                #if np.min(self.cX).f < self.results.cHistory[-1].f:
-                    #self.results.cHistory.append(np.min(self.cX).copy()) # superseded by progress_log()
-                self._progress_log(remark='(FWA)')
+                self._progress_log()
     
                 # Check stopping conditions
                 if self._stopping_criteria():
@@ -694,8 +689,7 @@ class MMO(Optimizer):
                         self.Trials = self.Trials[:N_new]          
                     
                 # Update history
-                # self.results.cHistory.append(self.best.copy()) # superseded by progress_log()
-                self._progress_log(remark='(DE)')
+                self._progress_log()
                 
                 # Check stopping conditions
                 if self._stopping_criteria():
