@@ -43,6 +43,8 @@ class CEC2014():
         """High Conditioned Elliptic Function"""
         d = np.size(x)
         return np.sum(np.power(1e6, np.arange(d) / (d - 1)) * np.power(x, 2))
+    f1.lb = -100
+    f1.ub = 100
 
     def f2(self, x):
         """Bent Cigar Function"""
@@ -133,12 +135,12 @@ class CEC2014():
 
     def f14(self, x):
         """Expanded Scaffer’s F6 Function"""
-        # TODO: Replace lambda with a function (pep8 E731)
-        def g(X, Y): return 0.5 + (np.sin((X**2 + Y**2)**0.5)
-                                   ** 2 - 0.5) / (1 + 0.001 * (X**2 + Y**2))**2
+        def g(X, Y): 
+            return 0.5 + (np.sin((X**2 + Y**2)**0.5) ** 2 - 0.5) \
+                        / (1 + 0.001 * (X**2 + Y**2))**2
         """
         # Possible speedup - needs to be tested
-        def gg(x, y):
+        def g_fast(x, y):
             xy2 = x**2 + y**2
             return 0.5 + (np.sin(np.sqrt(xy2))**2-0.5) / (1 + 0.001 * xy2)**2
         """
@@ -463,21 +465,6 @@ if __name__ == '__main__':
     x = np.random.uniform(-100, 100, 10)
     cec = CEC2014(10)
     test_functions = cec.functions
-#    test_functions = [cec.f1, cec.f2, cec.f3, cec.f4, cec.f5, cec.f6, cec.f7,
-#                      cec.f8, cec.f9, cec.f10, cec.f11, cec.f12, cec.f13, cec.f14,
-#                      cec.F1, cec.F2, cec.F3, cec.F4, cec.F5, cec.F6, cec.F7,
-#                      cec.F8, cec.F9, cec.F10, cec.F11, cec.F12, cec.F13,
-#                      cec.F14, cec.F15, cec.F16, cec.F17, cec.F18, cec.F19,
-#                      cec.F20, cec.F21, cec.F22, cec.F23, cec.F24, cec.F25,
-#                      cec.F26, cec.F27, cec.F28, cec.F29, cec.F30]
 
     for f in test_functions:
         print('%3s %s\n %20f' % (f.__name__, f.__doc__, f(x)))
-
-    # import time
-    # start = time.time()
-    # for r in range(1000*10*10):
-    #     # print(r)
-    #     cec.F7(x)
-    # end = time.time()
-    # print(end - start)
